from kindtool import cli, __app_name__

def main():
    cli.main()

if __name__ == "__main__":
    main()